// mijdbctest3.java
//
// simple test prepared statements
//
// Erwin Kalvelagen, TNO FEL
// Copyright (c) 1996 Bradley McLean / Jeffrey Medeiros
//
// You may distribute under the terms of the GNU Public License as
// specified in the README file that comes with the JavaPostgres95 Kit

import java.sql.*;
import java.math.*;
import java.io.*;
import mijdbc.*;


class mijdbctest3 {

   public static void main(String argv[]) {
      try {

	// explicit instantiation of the Driver
	// handy during development: forces recompile
	// of changed mijdbc sources.
	Driver mid = (Driver) new mijdbc.MIDriver();
	// in other cases one would use a late binding:
	//Class.forName( "mijdbc.MIDriver" );

			
	String url = "jdbc:mijdbc://134.203.33.12:7532/erwin";
	
	//java.util.Properties info = new java.util.Properties();
	//info.addProperty("user","emfh7");
	//info.addProperty("password","");

	Connection conn = DriverManager.getConnection(url,"emfh7","");
	
	Statement stat = conn.createStatement();

	exec(stat,"create table mijdbctest (i integer, t text);");

	
	PreparedStatement pstat = conn.prepareStatement("insert into mijdbctest values(?,?);");

	int[] iarray = {1,2,3};
	String[] sarray = {"one","two","three"};

	for (int i=0; i< 3; ++i) {
	  pstat.setInt(1,iarray[i]);
	  pstat.setString(2,sarray[i]);
	  int rows = pstat.executeUpdate();
	  System.out.println("rows inserted:"+rows);
	}
	exec(stat,"select * from mijdbctest;");
	exec(stat,"drop table mijdbctest;");


	conn.close();

      } catch ( Exception e ) {
         System.err.println("E: "+e);
	 e.printStackTrace();
      }
   }

  private static void exec(Statement stat, String s) throws SQLException {
    
    int updatecount;
    
    try {
      System.out.println(s);
      stat.execute(s);
      updatecount = stat.getUpdateCount();
      System.out.println("  update count= "+updatecount);
      if (updatecount == -1) {
	ResultSet rs = stat.getResultSet(); 
	if (rs == null) 
	  System.out.println("resultset is null!");
	else 
	  displayResults(rs);
      }
      
    } catch (Exception e) {
      throw new SQLException(""+e);
    }
    
    
  }
  

  private static void displayResults(ResultSet rs) throws SQLException {

    int i;
    int rowcnt = 0;


    try {
      
      
      ResultSetMetaData rsmd = rs.getMetaData();
      
      int numcols = rsmd.getColumnCount();
      System.out.println("  column count= "+numcols);

      System.out.print("  column names= ");
      for (i=1; i<=numcols; ++i) {
	if (i>1) System.out.print(", ");
	System.out.print(rsmd.getColumnName(i));
      }
      System.out.println("");

      System.out.print("  column types= ");
      for (i=1; i<=numcols; ++i) {
	if (i>1) System.out.print(", ");
	System.out.print(rsmd.getColumnTypeName(i));
      }
      System.out.println("");

 
      while (rs.next()) {
	
	System.out.print("  row "+ (++rowcnt) + "= ");
	for (i=1; i<=numcols; ++i) {
	  if (i>1) System.out.print(", ");
	  System.out.print(rs.getString(i));
	}
	System.out.println("");	

      }
     
    } catch (Exception e) {
      throw new SQLException(""+e);
    }
  }

}



